// 许可协议：萌绘图站开发组 MIT
var NavControl = {};

window.onload = function()
{
	NavControl.isReady = false;
	NavControl.init();	
}

/*
 * 第一步：当窗口加载时开始请求子页面并插入到 Tab 中
 */
NavControl.init = function ()
{
	// 是否载入 FileIO 库
	if (typeof(FileIO) === "object" && typeof(FileIO.readFile) === "function")
	{
		var counter = 0;
		var $content = document.querySelectorAll('#content')[0];
		var $tabs = $content.querySelectorAll('#content > .mui-control-content > .title');
		
		// 遍历全部选项卡，并加载子页面内容
		for (i = 0; i < $tabs.length; ++i) {
			var destPage = $tabs[i].getAttribute('href');
			var thisTab = $tabs[i];
			FileIO.readFile(destPage, function(html) {
				if (html != null)
					thisTab.innerHTML = html;
				
				// 如果全部加载完毕则回调 onNavLoad 方法
				if (++counter == $tabs.length) {
					if (typeof(window.onNavLoad) === "function")
					{
						NavControl.isReady = true;
						window.onNavLoad.call();
					}
				}
			});
		}
	}
	else
	{
		console.error("未找到 FileIO 库");
	}
}

/*
 * 第二步：子页面插入完成后开始调用 Callback 方法
 *         这里可以导入 VUE 或者 MUI 方法
 */
NavControl.ready = function(callback)
{
	var listener = setInterval(function()
	{
		if (NavControl.isReady)
		{
			callback.call();
			clearInterval(listener);
		}
	}, 100);
}

/*
 * 第三步：当上面的 Callback 触发时且 MUI 加载后调用该方法
 */
NavControl.muiLoaded = function()
{
	var $content = document.querySelectorAll('#content')[0];
	var $tabs = $content.querySelectorAll('#content > .mui-control-content');
		
	// 如果不是第一个选项卡，默认移除 mui-active 标签
	// 延时原因：等待 MUI 加载完毕，不然标签页的滚动条不会动
	setTimeout(function() {
		for (i = 0; i < $tabs.length; ++i) {
			if (i != 0)
				$tabs[i].className = 'mui-control-content';
		}
	}, 300);
	
	// 不明原因导致 MUI 在某些设备渲染失败
	// 隐藏一下 body 再显示让 MUI 重新渲染
	var $body = document.querySelector('body');
	$body.style.display = 'none';
	setTimeout(function() {
		$body.style.display = '';
	}, 150);
}



/**
 * 典型使用方法
 */
/*
<script src="js/mui-nav.js"></script>
<script src="js/vue.min.js"></script>
<script type="text/javascript">
window.onNavLoad = function() 
{

	【VUE 必须在 MUI 之前加载，否则会导致 MUI 控件失效】
	使用 window.vm1 定义方便其他区域调用该方法
	
	window.vm1 = new Vue(
	{
		.... Vue 代码区域
	});
		
	window.vm2 = new Vue(
	{
		.... Vue 代码区域
	});
	
	
	FileIO.loadJs('js/mui.min.js', function() 
	{
		mui.init();
		NavControl.muiLoaded();
		window.muiReady = true;
		
		.... MUI 代码区域
		
	});
}
</script>
 */

/**
 * 典型的 muiReady 监听器
 */
/*
 var muiListener = setInterval(function()
{
	// 当 MUI 初始化完成
	if (window.muiReady === true)
	{
		.... MUI 代码
		
		
		// 当 H5+ 就绪后执行
		mui.plusReady (function()
		{
	        .... H5+ 或 MUI 代码
	    });
	    
	    // 停止监听
		clearInterval(muiListener);
	}
}, 100);
 */